# {{TITLE}} Architecture Document

**Project:** {{project_name}}
**Date:** {{date}}
**Author:** {{user_name}}

## Executive Summary

{{executive_summary}}

## 1. Technology Stack and Decisions

### 1.1 Technology and Library Decision Table

{{technology_table}}

## 2. Architecture Overview

{{architecture_overview}}

## 3. Data Architecture

{{data_architecture}}

## 4. Component and Integration Overview

{{component_overview}}

## 5. Architecture Decision Records

{{architecture_decisions}}

## 6. Implementation Guidance

{{implementation_guidance}}

## 7. Proposed Source Tree

```
{{source_tree}}
```

## 8. Testing Strategy

{{testing_strategy}}
{{testing_specialist_section}}

## 9. Deployment and Operations

{{deployment_operations}}
{{devops_specialist_section}}

## 10. Security

{{security}}
{{security_specialist_section}}

---

## Specialist Sections

{{specialist_sections_summary}}

---

_Generated using BMad Method Solution Architecture workflow_
